###############################################################################
#                                                                             #
# Copyright (C) 2004-2015 Edward d'Auvergne                                   #
#                                                                             #
# This file is part of the program relax (http://www.nmr-relax.com).          #
#                                                                             #
# This program is free software: you can redistribute it and/or modify        #
# it under the terms of the GNU General Public License as published by        #
# the Free Software Foundation, either version 3 of the License, or           #
# (at your option) any later version.                                         #
#                                                                             #
# This program is distributed in the hope that it will be useful,             #
# but WITHOUT ANY WARRANTY; without even the implied warranty of              #
# MERCHANTABILITY or FITNESS FOR A PARTICULAR PURPOSE.  See the               #
# GNU General Public License for more details.                                #
#                                                                             #
# You should have received a copy of the GNU General Public License           #
# along with this program.  If not, see <http://www.gnu.org/licenses/>.       #
#                                                                             #
###############################################################################

# Package docstring.
"""Package of analysis independent code."""

# The available modules.
__all__ = [
    'align_tensor',
    'angles',
    'bmrb',
    'bruker',
    'chemical_shift',
    'dasha',
    'diffusion_tensor',
    'domain',
    'eliminate',
    'error_analysis',
    'exp_info',
    'fix',
    'grace',
    'interatomic',
    'j_coupling',
    'minimise',
    'model_selection',
    'mol_res_spin',
    'molmol',
    'noesy',
    'opendx',
    'palmer',
    'paramag',
    'pcs',
    'pipes',
    'plotting',
    'pymol_control',
    'rdc',
    'relax_data',
    'reset',
    'result_files',
    'results',
    'script',
    'selection',
    'sequence',
    'spectrometer',
    'spectrum',
    'state',
    'statistics',
    'structure',
    'value',
    'vmd'
]
